@@ -1,4 +1,7 @@
-NonRobust_bin <- function(g, y, e,iterations,sparse,debugging){
+NonRobust_bin <- function(g, y, e,iterations,prior,debugging){
+  if (prior %in% c("HS", "HS+", "RHS")) {
+    stop("The specified prior is currently not supported. Only 'SS' (spike-and-slab) prior is implemented.")
+  }
   
   p = dim(g)[2]
   
@@ -31,9 +34,10 @@ NonRobust_bin <- function(g, y, e,iterations,sparse,debugging){
   progress=0
   
   progress = ifelse(debugging, 10^(floor(log10(iterations))-1), 0)
-  if(sparse){
+  if(prior == "SS"){
     fit=BBLSS(g, y, ystar, w, iterations, hatAlpha, hatBeta, hatInvTauSq, invSigAlpha0, hatPi, hatLambdaSq, hatSigmaSq, aStar, bStar, alpha, gamma, sh1, sh0, progress)}
-  else{fit=BBL(g, y, ystar, w, iterations, hatBeta, hatAlpha, hatInvTauSq, invSigAlpha0, hatLambdaSq, hatSigmaSq, aStar, bStar, alpha, gamma, progress)}
+  else if (prior == "Laplace"){fit=BBL(g, y, ystar, w, iterations, hatBeta, hatAlpha, hatInvTauSq, invSigAlpha0, hatLambdaSq, hatSigmaSq, aStar, bStar, alpha, gamma, progress)}
+  else{stop("The specified prior is currently not supported.")}
   out=list(fit=fit,iterations=iterations)
   return(out)
 }
\ No newline at end of file
