@@ -1,5 +1,5 @@
 pqrBayes_lin <- function(g, y, e, quant = 0.5, iterations = 10000, burn.in,
-                         robust = TRUE, sparse = TRUE,
+                         robust = TRUE, prior = "SS",
                          hyper = NULL, debugging = FALSE) {
   
   # Check iterations and burn-in
@@ -16,9 +16,9 @@ pqrBayes_lin <- function(g, y, e, quant = 0.5, iterations = 10000, burn.in,
   
   # Call appropriate model
     if (robust) {
-      out <- Robust_lin(g, y, e, quant, iterations, sparse, hyper, debugging)
+      out <- Robust_lin(g, y, e, quant, iterations, prior, hyper, debugging)
     } else {
-      out <- NonRobust_lin(g, y, e, iterations, sparse, debugging)
+      out <- NonRobust_lin(g, y, e, iterations, prior, debugging)
     }
   
   # Extract posterior samples
